balafon
===============================================

.. image:: https://semaphoreci.com/api/v1/ljean/balafon/branches/master/badge.svg

Overview
------------------------------------

balafon moto is Organize > Target > Communicate. It helps you to work with your contacts in your day-to-day work


License
=======

CeCCIL 2.1. see license.txt
